@@ -6,10 +6,12 @@ import os
 from academic_metrics.constants import LOG_DIR_PATH
 
 RELEASE_MODE = True
+LOG_TO_CONSOLE = False
+LOG_LEVEL = logging.INFO
 
 if RELEASE_MODE:
-    LOG_TO_CONSOLE = True  # Keep console logging for warnings/errors
-    LOG_LEVEL = logging.WARNING  # Only show WARNING and above in release
+    LOG_TO_CONSOLE = True
+    LOG_LEVEL = logging.WARNING
 else:
     LOG_TO_CONSOLE = True
     LOG_LEVEL = logging.DEBUG
@@ -54,18 +56,6 @@ class ColorFormatter(logging.Formatter):
         return super().format(record)
 
 
-# Default = True (i.e. log messages will be displayed in the console).
-# True is the default to eliminate the need to jump between log files
-# to monitor the program's output during pre-release development.
-#
-# ! If the package is no longer in pre-release development,
-# ! this should be set to False to reduce program runtime overhead.
-# ! and to not overwhelm potential non-technical end-users.
-LOG_TO_CONSOLE = True
-
-# Default = DEBUG (i.e. all log messages will be displayed)
-LOG_LEVEL = logging.DEBUG
-
 # Keep track of configured loggers to
 # avoid re-configuring the same logger multiple times
 # for seperate class instances.
@@ -103,12 +93,13 @@ if os.environ.get("READTHEDOCS") != "True":
         _config_file_formatter = logging.Formatter(
             "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
         )
-        _config_color_formatter = ColorFormatter(
-            "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
-        )
         _file_handler.setFormatter(_config_file_formatter)
         _config_logger.addHandler(_file_handler)
 
+    _config_color_formatter = ColorFormatter(
+        "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
+    )
+
     if LOG_TO_CONSOLE:
         _console_handler = logging.StreamHandler()
         _console_handler.setLevel(LOG_LEVEL)
